@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-cookie-manager.c,v 1.4 2003/11/26 13:26:37 chpe Exp $
+ *  $Id: ephy-cookie-manager.c,v 1.5 2004/01/01 22:54:10 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -229,7 +229,7 @@ ephy_cookie_manager_base_init (gpointer base_iface)
 GList *
 ephy_cookie_manager_list_cookies (EphyCookieManager *manager)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_CLASS (manager);
+	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	return iface->list (manager);
 }
 
@@ -244,7 +244,7 @@ void
 ephy_cookie_manager_remove_cookie (EphyCookieManager *manager,
 				   const EphyCookie *cookie)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_CLASS (manager);
+	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	iface->remove (manager, cookie);
 }
 
@@ -257,6 +257,6 @@ ephy_cookie_manager_remove_cookie (EphyCookieManager *manager,
 void
 ephy_cookie_manager_clear (EphyCookieManager *manager)
 {
-	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_CLASS (manager);
+	EphyCookieManagerIFace *iface = EPHY_COOKIE_MANAGER_GET_IFACE (manager);
 	iface->clear (manager);
 }
