@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.26 2004/01/24 09:56:44 marco Exp $
+ *  $Id: ephy-dialog.c,v 1.27 2004/01/24 18:41:33 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -968,11 +968,18 @@ setup_default_size (EphyDialog *dialog)
 {
 	if (dialog->priv->has_default_size == FALSE)
 	{
+		EphyStateWindowFlags flags;
+
+		flags = EPHY_STATE_WINDOW_SAVE_SIZE;
+
+		if (dialog->priv->persist_position)
+		{
+			flags |= EPHY_STATE_WINDOW_SAVE_POSITION;
+		}
+
 		ephy_state_add_window (dialog->priv->dialog,
 				       dialog->priv->name, -1, -1,
-				       dialog->priv->persist_position ?
-				       EPHY_STATE_WINDOW_SAVE_POSITION :
-				       EPHY_STATE_WINDOW_SAVE_SIZE);
+				       flags);
 
 		dialog->priv->has_default_size = TRUE;
 	}
