@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.h,v 1.5 2003/11/08 12:56:43 chpe Exp $
+ *  $Id: ephy-file-helpers.h,v 1.6 2004/01/22 19:23:05 clahey Exp $
  */
 
 #ifndef EPHY_FILE_HELPERS_H
@@ -34,18 +34,21 @@ void        ephy_file_helpers_init       (void);
 
 void        ephy_file_helpers_shutdown   (void);
 
+char       *ephy_file_tmp_directory	 (void);
 char       *ephy_file_tmp_filename	 (const char *base,
 					  const char *extension);
 
 void	    ephy_ensure_dir_exists       (const char *dir);
 
 GSList     *ephy_file_find               (const char *path,
-	                                  const char *fname,
-	                                  gint maxdepth);
+				          const char *fname,
+				          gint maxdepth);
 
 gboolean    ephy_file_switch_temp_file   (const char *filename,
 					  const char *filename_temp);
 
+void	    ephy_file_delete_on_exit	 (const char *path);
+
 G_END_DECLS
 
 #endif /* EPHY_FILE_HELPERS_H */
