@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.c,v 1.8 2003/11/08 12:56:43 chpe Exp $
+ *  $Id: ephy-node-db.c,v 1.11 2004/01/10 16:35:46 chpe Exp $
  */
 
 #include "ephy-node-db.h"
@@ -40,7 +40,8 @@ static void ephy_node_db_finalize (GObject *object);
 enum
 {
 	PROP_0,
-	PROP_NAME
+	PROP_NAME,
+	PROP_IMMUTABLE,
 };
 
 #define EPHY_NODE_DB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_DB, EphyNodeDbPrivate))
@@ -48,11 +49,10 @@ enum
 struct EphyNodeDbPrivate
 {
 	char *name;
+	gboolean immutable;
 
-	GMutex *id_factory_lock;
 	long id_factory;
 
-	GStaticRWLock *id_to_node_lock;
 	GPtrArray *id_to_node;
 };
 
@@ -114,10 +114,12 @@ ephy_node_db_get_property (GObject *object,
 		case PROP_NAME:
 			g_value_set_string (value, db->priv->name);
 			break;
+		case PROP_IMMUTABLE:
+			g_value_set_boolean (value, ephy_node_db_is_immutable (db));
+			break;
 	}
 }
 
-
 static void
 ephy_node_db_set_property (GObject *object,
                            guint prop_id,
@@ -133,6 +135,9 @@ ephy_node_db_set_property (GObject *object,
 		case PROP_NAME:
 			ephy_node_db_set_name (db, g_value_get_string (value));
 			break;
+		case PROP_IMMUTABLE:
+			ephy_node_db_set_immutable (db, g_value_get_boolean (value));
+			break;
 	}
 }
 
@@ -155,6 +160,14 @@ ephy_node_db_class_init (EphyNodeDbClass *klass)
                                                                NULL,
                                                                G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+                                         PROP_IMMUTABLE,
+                                         g_param_spec_boolean  ("immutable",
+								"Immutable",
+								"Immutable",
+								FALSE,
+								G_PARAM_READWRITE));
+
 	g_type_class_add_private (object_class, sizeof (EphyNodeDbPrivate));
 }
 
@@ -168,12 +181,8 @@ ephy_node_db_init (EphyNodeDb *db)
 	/* id to node */
 	db->priv->id_to_node = g_ptr_array_new ();
 
-	db->priv->id_to_node_lock = g_new0 (GStaticRWLock, 1);
-	g_static_rw_lock_init (db->priv->id_to_node_lock);
-
 	/* id factory */
 	db->priv->id_factory = RESERVED_IDS;
-	db->priv->id_factory_lock = g_mutex_new ();
 }
 
 static void
@@ -189,10 +198,6 @@ ephy_node_db_finalize (GObject *object)
 
 	g_ptr_array_free (db->priv->id_to_node, FALSE);
 
-	g_static_rw_lock_free (db->priv->id_to_node_lock);
-
-	g_mutex_free (db->priv->id_factory_lock);
-
 	g_free (db->priv->name);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -239,17 +244,27 @@ ephy_node_db_get_name (EphyNodeDb *db)
 	return db->priv->name;
 }
 
+gboolean
+ephy_node_db_is_immutable (EphyNodeDb *db)
+{
+	return db->priv->immutable;
+}
+
+void
+ephy_node_db_set_immutable (EphyNodeDb *db, gboolean immutable)
+{
+	db->priv->immutable = immutable;
+
+	g_object_notify (G_OBJECT (db), "immutable");
+}
+
 EphyNode *
 ephy_node_db_get_node_from_id (EphyNodeDb *db, long id)
 {
 	EphyNode *ret = NULL;
 
-	g_static_rw_lock_reader_lock (db->priv->id_to_node_lock);
-
 	ret = node_from_id_real (db, id);
 
-	g_static_rw_lock_reader_unlock (db->priv->id_to_node_lock);
-
 	return ret;
 }
 
@@ -258,8 +273,6 @@ _ephy_node_db_new_id (EphyNodeDb *db)
 {
 	long ret;
 
-	g_mutex_lock (db->priv->id_factory_lock);
-
 	while (node_from_id_real (db, db->priv->id_factory) != NULL)
 	{
 		db->priv->id_factory++;
@@ -267,8 +280,6 @@ _ephy_node_db_new_id (EphyNodeDb *db)
 
 	ret = db->priv->id_factory;
 
-	g_mutex_unlock (db->priv->id_factory_lock);
-
 	return ret;
 }
 
@@ -277,29 +288,21 @@ _ephy_node_db_add_id (EphyNodeDb *db,
 		      long id,
 		      EphyNode *node)
 {
-	g_static_rw_lock_writer_lock (db->priv->id_to_node_lock);
-
 	/* resize array if needed */
 	if (id >= db->priv->id_to_node->len)
 		g_ptr_array_set_size (db->priv->id_to_node, id + 1);
 
 	g_ptr_array_index (db->priv->id_to_node, id) = node;
-
-	g_static_rw_lock_writer_unlock (db->priv->id_to_node_lock);
 }
 
 void
 _ephy_node_db_remove_id (EphyNodeDb *db,
 			 long id)
 {
-	g_static_rw_lock_writer_lock (db->priv->id_to_node_lock);
-
 	g_ptr_array_index (db->priv->id_to_node, id) = NULL;
 
 	/* reset id factory so we use the freed node id */
 	db->priv->id_factory = RESERVED_IDS;
-
-	g_static_rw_lock_writer_unlock (db->priv->id_to_node_lock);
 }
 
 gboolean
@@ -310,6 +313,7 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 {
 	xmlTextReaderPtr reader;
 	gboolean success = TRUE;
+	gboolean was_immutable;
 	int ret;
 
 	LOG ("ephy_node_db_load_from_file %s", xml_file)
@@ -327,6 +331,9 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 		return FALSE;
 	}
 
+	was_immutable = db->priv->immutable;
+	db->priv->immutable = FALSE;
+
 	ret = xmlTextReaderRead (reader);
 	while (ret == 1)
 	{
@@ -375,6 +382,8 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 
 	xmlFreeTextReader (reader);
 
+	db->priv->immutable = was_immutable;
+
 	STOP_PROFILER ("loading node db")
 
 	return (success && ret == 0);
@@ -446,7 +455,6 @@ ephy_node_db_write_to_xml_valist (EphyNodeDb *db,
 				if (ret < 0) break;
 			}
 		}
-		ephy_node_thaw (node);
 		if (ret < 0) break;
 
 		g_slist_free (exceptions);
