@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2000, 2001, 2002, 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.9 2003/12/19 20:16:51 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c,v 1.13 2004/01/23 18:07:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,10 +27,12 @@
 #include "ephy-encodings.h"
 #include "ephy-embed.h"
 #include "ephy-embed-shell.h"
+#include "ephy-file-helpers.h"
 #include "ephy-shell.h"
 #include "ephy-node.h"
 #include "ephy-node-view.h"
 #include "ephy-debug.h"
+#include "ephy-gui.h"
 
 #include <gtk/gtklabel.h>
 #include <gtk/gtkbutton.h>
@@ -74,7 +76,7 @@ struct EphyEncodingDialogPrivate
 static void	ephy_encoding_dialog_class_init		(EphyEncodingDialogClass *klass);
 static void	ephy_encoding_dialog_init		(EphyEncodingDialog *ge);
 void		ephy_encoding_dialog_response_cb	(GtkWidget *widget,
-							 gint response,
+							 int response,
 							 EphyEncodingDialog *dialog);
 
 static GObjectClass *parent_class = NULL;
@@ -82,9 +84,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_encoding_dialog_get_type (void)
 {
-	static GType ephy_type_encoding_dialog = 0;
+	static GType type = 0;
 
-	if (ephy_type_encoding_dialog == 0)
+	if (type == 0)
 	{
 		static const GTypeInfo our_info =
 		{
@@ -99,12 +101,12 @@ ephy_encoding_dialog_get_type (void)
 			(GInstanceInitFunc) ephy_encoding_dialog_init
 		};
 
-		ephy_type_encoding_dialog = g_type_register_static (EPHY_TYPE_EMBED_DIALOG,
-								    "EphyEncodingDialog",
-								    &our_info, 0);
+		type = g_type_register_static (EPHY_TYPE_EMBED_DIALOG,
+					       "EphyEncodingDialog",
+					       &our_info, 0);
 	}
 
-	return ephy_type_encoding_dialog;
+	return type;
 }
 
 static void
@@ -127,8 +129,8 @@ sync_embed_cb (EphyEncodingDialog *dialog, GParamSpec *pspec, gpointer dummy)
 	info = ephy_embed_get_encoding_info (embed);
 	if (info == NULL) return;
 
-	node = ephy_encodings_get_node (dialog->priv->encodings, info->encoding);
-	if (!EPHY_IS_NODE (node)) return;
+	node = ephy_encodings_get_node (dialog->priv->encodings, info->encoding, TRUE);
+	g_assert (EPHY_IS_NODE (node));
 
 	/* select the current encoding in the list view */
 	ephy_node_view_select_node (EPHY_NODE_VIEW (dialog->priv->enc_view),
@@ -240,9 +242,15 @@ activate_choice (EphyEncodingDialog *dialog)
 
 void
 ephy_encoding_dialog_response_cb (GtkWidget *widget,
-				  gint response,
+				  int response,
 				  EphyEncodingDialog *dialog)
 {
+	if (response == GTK_RESPONSE_HELP)
+	{
+		ephy_gui_help (GTK_WINDOW (widget), "epiphany", "text-encoding");
+		return;
+	}
+
 	g_object_unref (dialog);
 }
 
@@ -310,8 +318,9 @@ ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 
 	ephy_dialog_construct (EPHY_DIALOG (dialog),
 			       properties,
-			       "epiphany.glade",
-			       "encoding_dialog");
+			       ephy_file ("epiphany.glade"),
+			       "encoding_dialog",
+			       NULL);
 
 	dialog->priv->filter = ephy_node_filter_new ();
 
