@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 200-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.61 2003/12/26 19:38:41 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.71 2004/01/24 12:09:48 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +39,7 @@
 #include "ephy-debug.h"
 #include "ephy-ellipsizing-label.h"
 #include "ephy-file-chooser.h"
+#include "ephy-file-helpers.h"
 #include "ephy-tree-model-node.h"
 #include "ephy-tree-model-sort.h"
 
@@ -255,7 +256,7 @@ EphyDialogProperty properties [] =
 	{ "homepage_entry",			CONF_GENERAL_HOMEPAGE,	  PT_AUTOAPPLY,	G_TYPE_STRING },
 	{ "homepage_current_button",		NULL,			  PT_NORMAL,	0 },
 	{ "homepage_blank_button",		NULL,			  PT_NORMAL,	0 },
-	{ "auto_open_downloads_checkbutton",	CONF_AUTO_OPEN_DOWNLOADS, PT_AUTOAPPLY,	0 },
+	{ "automatic_downloads_checkbutton",	CONF_AUTO_DOWNLOADS,      PT_AUTOAPPLY,	0 },
 	{ "download_path_button",		NULL,			  PT_NORMAL,	0 },
 
 	/* Fonts and Colors */
@@ -407,14 +408,11 @@ prefs_dialog_show_help (EphyDialog *dialog)
 	GtkWidget *window, *notebook;
 	int id;
 
-	/* FIXME: Once we actually have documentation we
-	 * should point these at the correct links.
-	 */
 	char *help_preferences[] = {
-		"setting-preferences",
-		"setting-preferences",
-		"setting-preferences",
-		"setting-preferences"
+		"general-preferences",
+		"fonts-and-colors-preferences",
+		"privacy-preferences",
+		"language-preferences"
 	};
 
 	window = ephy_dialog_get_control (dialog, properties[WINDOW_PROP].id);
@@ -441,8 +439,7 @@ setup_font_combo (EphyDialog *dialog,
 	char key[255];
 	EphyEmbedSingle *single;
 
-	single = ephy_embed_shell_get_embed_single
-		(EPHY_EMBED_SHELL (ephy_shell));
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 	fonts = ephy_embed_single_get_font_list (single, code);
 
 	g_snprintf (key, 255, "%s_%s_%s", CONF_RENDERING_FONT, type, code);
@@ -594,7 +591,7 @@ create_node_combo (EphyDialog *dialog,
 	int title_col, data_col;
 
 	code = eel_gconf_get_string (key);
-	if (code == NULL || ephy_encodings_get_node (encodings, code) == NULL)
+	if (code == NULL || ephy_encodings_get_node (encodings, code, FALSE) == NULL)
 	{
 		/* safe default */
 		eel_gconf_set_string (key, default_value);
@@ -798,8 +795,11 @@ setup_add_language_dialog (PrefsDialog *pd)
 					     "parent-window", window,
 					     NULL));
 
-	ephy_dialog_construct (dialog,  add_lang_props,
-			       "prefs-dialog.glade", "add_language_dialog");
+	ephy_dialog_construct (dialog, 
+			       add_lang_props,
+			       ephy_file ("prefs-dialog.glade"),
+			       "add_language_dialog",
+			       NULL);
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -1084,21 +1084,24 @@ create_language_section (EphyDialog *dialog)
 static char*
 get_download_button_label ()
 {
-	char *label, *key, *desktop_path, *home_path, *tmp;
+	char *key, *label, *downloads_path;
 
 	key = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+	downloads_path = g_build_path (g_get_home_dir (), "Desktop",
+				       _("Downloads"), NULL);
 
-	tmp = g_build_filename (g_get_home_dir (), "Desktop", NULL);
-	desktop_path = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
-	home_path = g_filename_to_utf8 (g_get_home_dir (), -1, NULL, NULL, NULL);
-	g_free (tmp);
+	/* fallback to Home directory */
+	if (key == NULL)
+	{
+		key = g_strdup ("~");
+	}
 
-	if (g_utf8_collate (key, desktop_path) == 0)
+	if (g_utf8_collate (key, "~/Desktop") == 0)
 	{
 		g_free (key);
 		label = g_strdup (_("Desktop")); 
 	}
-	else if (g_utf8_collate (key, home_path) == 0)
+	else if (g_utf8_collate (key, "~") == 0)
 	{
 		g_free (key);
 		/* Note that this does NOT refer to the home page but to a
@@ -1107,13 +1110,18 @@ get_download_button_label ()
 		 * filechooser */
 		label = g_strdup (_("Home"));
 	}
+	else if (g_utf8_collate (key, downloads_path) == 0)
+	{
+		g_free (key);
+		label = g_strdup (_("Downloads"));
+	}
 	else
 	{
 		label = key;
 	}
 
-	g_free (desktop_path);
-	g_free (home_path);
+	g_free (downloads_path);
+
 	return label;
 }
 	
@@ -1150,8 +1158,9 @@ prefs_dialog_init (PrefsDialog *pd)
 
 	ephy_dialog_construct (dialog,
 			       properties,
-			       "prefs-dialog.glade",
-			       "prefs_dialog");
+			       ephy_file ("prefs-dialog.glade"),
+			       "prefs_dialog",
+			       NULL);
 
 	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
 			      n_cookies_accept_enum, cookies_accept_enum);
@@ -1230,9 +1239,7 @@ prefs_clear_cache_button_clicked_cb (GtkWidget *button,
 {
 	EphyEmbedSingle *single;
 
-	single = ephy_embed_shell_get_embed_single
-		(EPHY_EMBED_SHELL (ephy_shell));
-
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 	ephy_embed_single_clear_cache (single);
 }
 
@@ -1282,21 +1289,19 @@ download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 	{
 		char *dir;
 
-		dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (fc));
+		dir = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fc));
 		if (dir != NULL)
 		{
 			GtkWidget *button;
-			char *label, *converted;
+			char *label;
 
-			converted = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
-			eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, converted);
+			eel_gconf_set_path (CONF_STATE_DOWNLOAD_DIR, dir);
 			
 			button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
 			label = get_download_button_label ();
 			ephy_ellipsizing_label_set_text ((EphyEllipsizingLabel*) GTK_BIN (button)->child,
 							  label);
 
-			g_free (converted);
 			g_free (dir);
 			g_free (label);
 		}
